pub struct Server { /* private fields */ }Expand description
A server can handle multiple requests. It holds a single key pair and can generate a configuration. (A more complex server would have multiple key pairs. This is simple.)
Implementations